=======
Credits
=======

* [Oscar Cortez](https://github.com/oscarmcm)

Contributors
------------
* [Ivan](https://github.com/vanya909)
* [Darwing Medina](https://github.com/darwing1210)
* [pavillet](https://github.com/pavillet)
* [Dan Ryan](https://github.com/dryan)
* [Andrew Graham-Yooll](https://github.com/andrewgy8)

